"""
    Basis Theory API

    ## Getting Started * Sign-in to [Basis Theory](https://basistheory.com) and go to [Applications](https://portal.basistheory.com/applications) * Create a Basis Theory Server to Server Application * All permissions should be selected * Paste the API Key into the `BT-API-KEY` variable  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import basistheory
from basistheory.model.pagination import Pagination
from basistheory.model.tenant_invitation_response import TenantInvitationResponse
globals()['Pagination'] = Pagination
globals()['TenantInvitationResponse'] = TenantInvitationResponse
from basistheory.model.tenant_invitation_response_paginated_list import TenantInvitationResponsePaginatedList


class TestTenantInvitationResponsePaginatedList(unittest.TestCase):
    """TenantInvitationResponsePaginatedList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testTenantInvitationResponsePaginatedList(self):
        """Test TenantInvitationResponsePaginatedList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = TenantInvitationResponsePaginatedList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
