"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import basistheory
from basistheory.model.encryption_key import EncryptionKey
globals()['EncryptionKey'] = EncryptionKey
from basistheory.model.encryption_metadata import EncryptionMetadata


class TestEncryptionMetadata(unittest.TestCase):
    """EncryptionMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testEncryptionMetadata(self):
        """Test EncryptionMetadata"""
        # FIXME: construct object with mandatory attributes with example values
        # model = EncryptionMetadata()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
