"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import unittest

import basistheory
from basistheory.api.tokens_api import TokensApi  # noqa: E501


class TestTokensApi(unittest.TestCase):
    """TokensApi unit test stubs"""

    def setUp(self):
        self.api = TokensApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create(self):
        """Test case for create

        """
        pass

    def test_delete(self):
        """Test case for delete

        """
        pass

    def test_get_by_id(self):
        """Test case for get_by_id

        """
        pass

    def test_list(self):
        """Test case for list

        """
        pass

if __name__ == '__main__':
    unittest.main()
